###############################################################################################################################
###############################################################################################################################
###############################################################################################################################

        # Python script for Figures in following paper (c) by W. Yao, L. Puts, K. Williams and D. Lenstra
        # as part of the work published in "An All-Optical Spiking Laser Neuron Integrated in Generic 
        # InP Photonic Circuit Technology" published in Optics Express
        # 
        # This work is licensed under a Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License.
        # 
        # You should have received a copy of the license along with this work. If not, see 
        # <https://creativecommons.org/licenses/by-nc-sa/4.0/>.
        
        # Eindhoven Univesity of Technology, Eindhoven, the Netherlands, May 2025
        
        # Contact: l.puts@tue.nl

###############################################################################################################################
###############################################################################################################################
###############################################################################################################################

import matplotlib.pyplot as plt
import numpy as np

plt.rcParams['font.size'] = 14

file='VOA 0.0 Estimated pulsating frequency 2024-08-18_00_23_10.npy'
freq=np.load(file)

current=np.linspace(0,100,101)/1000
voltage=np.linspace(0,4,81)

freq_no_nan=np.nan_to_num(freq)

fig=plt.figure(4,figsize=(4.5,3))
fig.patch.set_alpha(0)
c=plt.contourf((current*1000),voltage,np.transpose(freq_no_nan)/1e6,levels=100, cmap=plt.cm.Reds)
plt.contour((current*1000),voltage,np.transpose(freq_no_nan)/1e6,levels=[94,110],linestyles='-', colors='black',alpha=1, linewidths=.8)
plt.hlines(2.4, 40, 100, linestyle='--', color='black')

plt.annotate( 'Excitable\noperation', xy=(52.5,1.878),
              xytext=(59.5,1.3),color='black', ha='center',
              arrowprops=dict( arrowstyle="->" ,color='black'),fontsize=10
            )

plt.annotate( 'Self\npulsations', xy=(76.5,1.878),
              xytext=(93,1.0),color='black', ha='center',
              arrowprops=dict( arrowstyle="->" ,color='black'),fontsize=10
            )

plt.annotate( 'Off', xy=(45,3),
              xytext=(46,3.2),color='black', ha='center',fontsize=10
              
            )

plt.annotate( 'Expect cw from sim.', xy=(76.5,1.878),
              xytext=(85,0.4),color='black', ha='center',fontsize=10
              
            )

cbar=plt.colorbar(c,ticks=[0,100,250,500,750,1000])
plt.xlabel(r'I$_{SOA}$ [mA]',fontsize=14)
plt.ylabel(r'V$_{rb}$ [V]',fontsize=14)
cbar.set_label(r'f$_{rep}$ [MHz]',fontsize=14)
plt.tight_layout()
plt.xlim([40,100])
plt.gca().invert_yaxis()
plt.ylim([3.5,0])


#%%2D SLICE WITH SQRT FIT    
plt.rcParams['font.size'] = 13

gamma=0.053
vg=299792458/3.68
a=2e-20
q=1.60217663e-19

L=1070e-6 
t_active = 100e-9       
w_active = 2e-6
V = L * t_active * w_active 

Ith=0.059
Ith_int=int(Ith*1000)
I=current[Ith_int:92]
I_model=np.linspace(current[Ith_int:92][0],current[Ith_int:92][-1],100)
I_full=current
eta_i=0.6

model=np.sqrt((gamma*vg*a)/(q*V)*eta_i*(I_model-Ith))/(2*np.pi)

fig=plt.figure(figsize=(4.5,3))
fig.patch.set_alpha(0)
plt.plot(I*1000,(np.transpose(freq[:,48][Ith_int:92])/1e9),'ko',markersize=4,label='Measured at V$_{rb}$ = 2.4V')
plt.plot(I_model*1000,model/1e9,'--k',label='Relaxation osc. model')
plt.grid()
plt.legend()
plt.xlabel(r'I$_{SOA}$ [mA]')
plt.ylabel('Frequency [GHz]')
plt.tight_layout()    